==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/atlantis/dialogs_es.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("¡Contempla eso!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("¡Nada más imagina!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("¡¿Quién lo habría pensado?!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Qué falta de cuidado.")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Miles perecieron - la ciudad entera desapareció en las olas por causa de tal ineptitud.")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Tapón destapado.")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Una equivocación embarazosa.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("¿Qué haremos con eso?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Podemos tratar de ponerlo de vuelta en su lugar.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("¿Y entonces? ¿Deberíamos beber toda el agua que se filtró, o qué?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens` heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Podemos ponerlo en su lugar como un símbolo de nuestra estima al heroico esfuerzo de los ciudadanos para mantenerlo a flote. Como un memorial a su ingenio, destreza y naturaleza persistente.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.` The Providence itself unplugged that hole. Just imagine you`d hear such things at home. Day by day.")
dialogStr("¿De qué? '¿Hacia donde corres? Necesito ordenar ocho espadas.` La Providencia misma destapó ese agujero. Sólo imagina si escucharas esas cosas en la casa. Día tras día.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Y además: ¿Es posible que cualquier persona pudiera venir alguna vez aquí? Sólo algunos moluscos lo mascarían de vez en cuando.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Nos vamos a sentir bien por eso.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Nos vamos a sentir mal por eso. ¿Crees que el jefe lo va a creer? ¿Un gigante destapó el tapón? ¿Y qué han hecho con eso? Lo tapamos de nuevo. He, he, he.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Podrías estar en lo correcto. Quizás sería mejor llevarlo.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Yo pienso igual, también.")


dialogId("sp-v-dotoho", "font_big", "Let `s get to work.")
dialogStr("Vamos a trabajar.")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("¿Que tal si sólo dejamos el tapón ahí?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("¿Qué diría la Agencia?")


dialogId("sp-v-jedno", "font_big", "I don`t think I mind what the boss is going to think about me.")
dialogStr("No creo que me importe lo que el jefe va a pensar de mi.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Espera. Esto ya está resuelto sin duda.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("El maldito tapón. Que tal si hacemos algo.")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("¿Como eso, por ejemplo?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Bueno, podríamos decir que la ciudad de hecho nunca existió")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Bien, podríamos decir que la ciudad se hundió porque el hielo del Artico se derritió.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Un terremoto pudo haber sumergido la ciudad, por ejemplo.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Un tsunami podría haber hundido la ciudad, por ejemplo.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Podríamos suponer que un volcán erupcionó en el centro de la ciudad.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Eso simplemente no tiene sentido.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("En esta ocasión nuestra meta es sacar ese tapón.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/atlantis/dialogs_es.lua <==

dialogId("sp-v-no0", "font_big", "Lo and behold!")
dialogStr("¡Contempla eso!")


dialogId("sp-m-no1", "font_small", "Just imagine!")
dialogStr("¡Nada más imagina!")


dialogId("sp-v-kdoby", "font_big", "Who could have guessed?!")
dialogStr("¡¿Quién lo habría pensado?!")


dialogId("sp-m-neopatrnost", "font_small", "Such carelessness.")
dialogStr("Qué falta de cuidado.")


dialogId("sp-v-zahynuli", "font_big", "Thousands perished - the whole city disappeared in the waves because of such ineptness.")
dialogStr("Miles perecieron - la ciudad entera desapareció en las olas por causa de tal ineptitud.")


dialogId("sp-m-vytazeny", "font_small", "Unplugged plug.")
dialogStr("Tapón destapado.")


dialogId("sp-v-trapne", "font_big", "An embarrassing blunder.")
dialogStr("Una equivocación embarazosa.")


dialogId("sp-m-costim", "font_small", "What are we to do with it?")
dialogStr("¿Qué haremos con eso?")


dialogId("sp-v-vratit0", "font_big", "We can try to put it back in place.")
dialogStr("Podemos tratar de ponerlo de vuelta en su lugar.")


dialogId("sp-m-vratit0", "font_small", "And then? Shall we drink the water that poured in, or what?")
dialogStr("¿Y entonces? ¿Deberíamos beber toda el agua que se filtró, o qué?")


dialogId("sp-v-vratit1", "font_big", "We can put it back in place as a token of our esteem of the citizens’ heroic effort to keep it afloat. As a memorial to their industrious, adroit and... persistent nature.")
dialogStr("Podemos ponerlo en su lugar como un símbolo de nuestra estima al heroico esfuerzo de los ciudadanos para mantenerlo a flote. Como un memorial a su ingenio, destreza y naturaleza persistente.")


dialogId("sp-m-vratit1", "font_small", "Of what? 'Where are you running? I need to order eight swords.’ The Providence itself unplugged that hole. Just imagine you’d hear such things at home. Day by day.")
dialogStr("¿De qué? '¿Hacia donde corres? Necesito ordenar ocho espadas.’ La Providencia misma destapó ese agujero. Sólo imagina si escucharas esas cosas en la casa. Día tras día.")


dialogId("sp-m-kalet", "font_small", "And moreover: is it likely that anybody would ever come here? Only sepias will nibble it occasionally.")
dialogStr("Y además: ¿Es posible que cualquier persona pudiera venir alguna vez aquí? Sólo algunos moluscos lo mascarían de vez en cuando.")


dialogId("sp-v-pocit", "font_big", "We are going to feel good about it.")
dialogStr("Nos vamos a sentir bien por eso.")


dialogId("sp-m-potize", "font_small", "We are going to feel down about it. Do you think the boss is going to believe it? A giant unplugged plug? And what have you done with it? We plugged it again. He, he, he.")
dialogStr("Nos vamos a sentir mal por eso. ¿Crees que el jefe lo va a creer? ¿Un gigante destapó el tapón? ¿Y qué han hecho con eso? Lo tapamos de nuevo. He, he, he.")


dialogId("sp-v-vzit", "font_big", "You might be right. Maybe it would be better to take it along.")
dialogStr("Podrías estar en lo correcto. Quizás sería mejor llevarlo.")


dialogId("sp-m-taky", "font_small", "I think so, too.")
dialogStr("Yo pienso igual, también.")


dialogId("sp-v-dotoho", "font_big", "Let ’s get to work.")
dialogStr("Vamos a trabajar.")


dialogId("sp-m-nechat", "font_small", "What if we just leave that plug here?")
dialogStr("¿Que tal si sólo dejamos el tapón ahí?")


dialogId("sp-v-centrala", "font_big", "What would the Agency say?")
dialogStr("¿Qué diría la Agencia?")


dialogId("sp-v-jedno", "font_big", "I don’t think I mind what the boss is going to think about me.")
dialogStr("No creo que me importe lo que el jefe va a pensar de mi.")


dialogId("sp-m-vydrz", "font_small", "Hold on. We are sure to solve it.")
dialogStr("Espera. Esto ya está resuelto sin duda.")


dialogId("sp-m-spunt", "font_small", "The darned plug. What if we just make up something.")
dialogStr("El maldito tapón. Que tal si hacemos algo.")


dialogId("sp-v-co", "font_big", "Like what, for example?")
dialogStr("¿Como eso, por ejemplo?")


dialogId("sp-m-vymluva0", "font_small", "Well, we could say that the city in fact never existed.")
dialogStr("Bueno, podríamos decir que la ciudad de hecho nunca existió")


dialogId("sp-m-vymluva1", "font_small", "Well, we could say that the city sank because the Arctic ice had melted.")
dialogStr("Bien, podríamos decir que la ciudad se hundió porque el hielo del Artico se derritió.")


dialogId("sp-m-vymluva2", "font_small", "An earthquake could have sunk the city, for example.")
dialogStr("Un terremoto pudo haber sumergido la ciudad, por ejemplo.")


dialogId("sp-m-vymluva3", "font_small", "A tsunami might have sunk the city, for example.")
dialogStr("Un tsunami podría haber hundido la ciudad, por ejemplo.")


dialogId("sp-m-vymluva4", "font_small", "We could try to say that a volcano erupted in the center of the city.")
dialogStr("Podríamos suponer que un volcán erupcionó en el centro de la ciudad.")


dialogId("sp-v-nesmysl", "font_big", "That is just nonsense.")
dialogStr("Eso simplemente no tiene sentido.")


dialogId("sp-v-ven", "font_big", "This time our goal is to get that plug out.")
dialogStr("En esta ocasión nuestra meta es sacar ese tapón.")
